"""
Flask-SES
=========

This tiny library will help you to send email using boto3 through AWS SES.
"""
from setuptools import setup


setup(
    name='ses-mail',
    version='1.0',
    url='https://github.com/michaeltcoelho/flask-ses',
    license='MIT',
    author='Michael Coelho',
    author_email='michael.tcoelho@gmail.com',
    description='Sending email using AWS SES',
    long_description=__doc__,
    packages=['flask_ses'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[
        'boto3'
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)



import boto3


class SESMailer:
    """AWS Simple Email Service Extension."""

    def __init__(self, app=None):
        """Initialize SES interface.

        :param app: Flask application
        """
        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        """Initialize SESMailer."""
        self.ses_sender = app.config.get('AWS_SES_SENDER')
        self.aws_region = app.config['AWS_SES_REGION_NAME']
        self.aws_access_key_id = app.config['AWS_ACCESS_KEY_ID']
        self.aws_secret_access_key = app.config['AWS_SECRET_ACCESS_KEY']

    @property
    def connection(self):
        if not hasattr(self, '_ses_mailer'):
            self._ses_mailer = boto3.client(
                'ses', region_name=self.aws_region,
                aws_access_key_id=self.aws_access_key_id,
                aws_secret_access_key=self.aws_secret_access_key,
            )
        return self._ses_mailer

    def send_email(self, recipients, sender=None, subject='', text='', html=''):
        """Send e-mail.

        :param recipients: Recipients e-mails list.
        :param sender: Sender e-mail.
        :param subject: E-mail subject.
        :param text: E-mail body as a text.
        :param html: E-mail body html.
        """
        if sender is None:
            sender = self.ses_sender

        email = self.connection.send_email(
            Source=sender,
            Destination={'ToAddresses': recipients},
            Message={
                'Subject': {'Data': subject},
                'Body': {
                    'Text': {'Data': text},
                    'Html': {'Data': html},
                }
            }
        )
        return email

